==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/calendar.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 *
 * $Id: calendar.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['nav_calendar'] = "Calendar";
$l['nav_viewevent'] = "View Event";
$l['nav_dayview'] = "Day View";
$l['nav_addevent'] = "Add Event";
$l['nav_editevent'] = "Edit Event";
$l['nav_move_event'] = "Move Event";

$l['calendar_disabled'] = "You cannot use the calendar functionality as it has been disabled by the Administrator.";

// In some languages these months need to be slightly different than those defined in global.lang.php
$l['alt_month_1'] = "January";
$l['alt_month_2'] = "February";
$l['alt_month_3'] = "March";
$l['alt_month_4'] = "April";
$l['alt_month_5'] = "May";
$l['alt_month_6'] = "June";
$l['alt_month_7'] = "July";
$l['alt_month_8'] = "August";
$l['alt_month_9'] = "September";
$l['alt_month_10'] = "October";
$l['alt_month_11'] = "November";
$l['alt_month_12'] = "December";

$l['add_private_event'] = "Add Private Event";
$l['add_public_event'] = "Add Public Event";

$l['calendar'] = "Calendar";

$l['jump_month'] ="Jump to month:";

$l['birthdays_on_day'] = "Birthdays on {1}";
$l['birthdayhidden'] = "Hidden";

$l['event'] = "event";
$l['events'] = "events";
$l['add_event'] = "Add Event";
$l['event_date'] = "Event Date:";
$l['event_recurring_start_date'] = "Start Date:";
$l['event_recurring_end_date'] = "End Date:";
$l['event_recurring_repeat_days'] = "Event Repeats On:";
$l['event_name'] = "Event Name:";
$l['event_details'] = "Event Details:";
$l['event_options'] = "Options:";
$l['private_option'] = "<b>Private</b> Only you will be able to view this event. (Registered Users Only).";
$l['delete_option'] = "<b>Delete:</b> Delete this event.";
$l['post_event'] = "Post Event";
$l['day_view'] = "Day View";
$l['birthday'] = "Birthday";
$l['birthdays'] = "Birthdays";
$l['event_author'] = "Event Author:";
$l['edit_event'] = "Edit Event";
$l['view_event'] = "View Event";
$l['no_events'] = "This day does not have any events associated with it.<p><a href=\"calendar.php?action=addevent&amp;calendar={1}&amp;day={2}&amp;month={3}&amp;year={4}\">Post an Event</a>.</p>";
$l['years_old'] = "{1} Years Old";
$l['alt_edit'] = "Edit this event";
$l['alt_delete'] = "Delete this event";
$l['moderator_options'] = "Moderator Options";
$l['approve_event'] = "Approve Event";
$l['unapprove_event'] = "Unapprove Event";
$l['move_event'] = "Move Event";
$l['repeats_every_day'] = "Repeats every day";
$l['repeats_every_x_days'] = "Repeats every {1} days";
$l['repeats_on_weekdays'] = "Repeats Monday through Friday";
$l['every_week_on_days'] = "Repeats every week on {1}";
$l['every_week'] = "Repeats every week";
$l['every_x_weeks_on_days'] = "Repeats every {1} weeks on<br />{2}";
$l['every_x_weeks'] = "Repeats every {1} weeks";
$l['every_month_on_day'] = "Repeats on day {1}<br />of every month";
$l['every_x_months_on_day'] = "Repeats on day {1}<br />of every {2} months";
$l['every_month_on_weekday'] = "Repeats on the {1} {2}<br />of every month";
$l['every_x_months_on_weekday'] = "Repeats on the {1} {2}<br />of every {3} months";
$l['weekday_occurance_1'] = "first";
$l['weekday_occurance_2'] = "second";
$l['weekday_occurance_3'] = "third";
$l['weekday_occurance_4'] = "fourth";
$l['weekday_occurance_last'] = "last";
$l['every_year_on_day'] = "Repeats every year on {1} {2}";
$l['every_x_years_on_day'] = "Repeats every {3} years on {1} {2}";
$l['every_year_on_weekday'] = "Repeats on the {1} {2} in {3} of every year";
$l['every_x_year_on_weekday'] = "Repeats on the {1} {2} in {3} every {4} years";
$l['delete_event'] = "Delete Event";
$l['delete_q'] = "Delete?";
$l['delete_1'] = "To delete this event, check the checkbox to the left and then click the button to the right.";
$l['delete_2'] = "<b>Note:</b> This process cannot be undone.";
$l['delete_now'] = "Delete Now";
$l['jump_to_calendar'] = "Jump to calendar:";
$l['select_calendar'] = "Calendar:";
$l['type_single'] = "Single day event";
$l['type_ranged'] = "Ranged or recurring event";
$l['enter_time'] = "Time:";
$l['start_time'] = "Starts:";
$l['end_time'] = "Finishes:";
$l['timezone'] = "Time Zone:";
$l['ignore_timezone'] = "<strong>Ignore time zone:</strong> This event should use the time zone of the viewer.";
$l['repeats'] = "Repeats:";
$l['does_not_repeat'] = "Does not repeat";
$l['repeats_daily'] = "Daily";
$l['repeats_weekdays'] = "Every weekday (Mon-Fri)";
$l['repeats_weekly'] = "Weekly";
$l['repeats_every'] = "Repeats every";
$l['day_or_days'] = "day(s)";
$l['week_or_weeks_on'] = "week(s) on";
$l['repeats_monthly'] = "Monthly";
$l['repeats_yearly'] = "Yearly";
$l['repeats_every'] = "Repeats every";
$l['repeats_on_day'] = "Repeats on day";
$l['of_every'] = "of every";
$l['month_or_months'] = "month(s)";
$l['repeats_on_the'] = "Repeats on the";
$l['day_of_every'] = "day every";
$l['repeats_on'] = "Repeats on";
$l['every'] = "every";
$l['year_or_years'] = "year(s)";
$l['of'] = "of";
$l['move_to_calendar'] = "Move to Calendar:";
$l['weekly_overview'] = "Weekly Overview:";
$l['previous_week'] = "Previous Week";
$l['next_week'] = "Next Week";
$l['first'] = "First";
$l['second'] = "Second";
$l['third'] = "Third";
$l['fourth'] = "Fourth";
$l['last'] = "Last";
$l['all_day'] = "All Day";
$l['starts'] = "Starts: ";
$l['finishes'] = "Finishes: ";

$l['error_incorrectday'] = "The day you have entered does not appear to exist. Please go back and try again.";
$l['error_invalidevent'] = "The event you specified is either invalid or doesn't exist.";
$l['invalid_calendar'] = "The specified calendar does not exist. Are you sure you are visiting the correct page?";
$l['redirect_eventdeleted'] = "The event has successfully been deleted.<br />You will now be taken back to the calendar.";
$l['redirect_eventupdated'] = "The event has been successfully updated.<br />You will now be returned to it.";
$l['redirect_eventadded'] = "Your event has been added successfully.<br />You will now be taken to it.";
$l['redirect_eventadded_moderation'] = "Your event has been added successfully but requires moderation by a forum moderator before it is visible.<br />You will now be taken back to the calendar.";
$l['redirect_eventunapproved'] = "The event has been unapproved successfully.<br />You will now be taken to it.";
$l['redirect_eventapproved'] = "The event has been approved successfully.<br />You will now be taken to it.";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/calendar.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 *
 * $Id: calendar.lang.php 5557 2011-08-26 14:06:44Z huji $
 */

$l['nav_calendar'] = "Calendar";
$l['nav_viewevent'] = "View Event";
$l['nav_dayview'] = "Day View";
$l['nav_addevent'] = "Add Event";
$l['nav_editevent'] = "Edit Event";
$l['nav_move_event'] = "Move Event";

$l['calendar_disabled'] = "You cannot use the calendar functionality as it has been disabled by the Administrator.";

// In some languages these months need to be slightly different than those defined in global.lang.php
$l['alt_month_1'] = "January";
$l['alt_month_2'] = "February";
$l['alt_month_3'] = "March";
$l['alt_month_4'] = "April";
$l['alt_month_5'] = "May";
$l['alt_month_6'] = "June";
$l['alt_month_7'] = "July";
$l['alt_month_8'] = "August";
$l['alt_month_9'] = "September";
$l['alt_month_10'] = "October";
$l['alt_month_11'] = "November";
$l['alt_month_12'] = "December";

$l['add_private_event'] = "Add Private Event";
$l['add_public_event'] = "Add Public Event";

$l['calendar'] = "Calendar";

$l['jump_month'] ="Jump to month:";

$l['birthdays_on_day'] = "Birthdays on {1}";
$l['birthdayhidden'] = "Hidden";

$l['event'] = "event";
$l['events'] = "events";
$l['add_event'] = "Add Event";
$l['event_date'] = "Event Date:";
$l['event_recurring_start_date'] = "Start Date:";
$l['event_recurring_end_date'] = "End Date:";
$l['event_recurring_repeat_days'] = "Event Repeats On:";
$l['event_name'] = "Event Name:";
$l['event_details'] = "Event Details:";
$l['event_options'] = "Options:";
$l['private_option'] = "<b>Private</b> Only you will be able to view this event. (Registered Users Only).";
$l['delete_option'] = "<b>Delete:</b> Delete this event.";
$l['post_event'] = "Post Event";
$l['day_view'] = "Day View";
$l['birthday'] = "Birthday";
$l['birthdays'] = "Birthdays";
$l['event_author'] = "Event Author:";
$l['edit_event'] = "Edit Event";
$l['view_event'] = "View Event";
$l['no_events'] = "This day does not have any events associated with it.<p><a href=\"calendar.php?action=addevent&amp;calendar={1}&amp;day={2}&amp;month={3}&amp;year={4}\">Post an Event</a>.</p>";
$l['years_old'] = "{1} Years Old";
$l['alt_edit'] = "Edit this event";
$l['alt_delete'] = "Delete this event";
$l['moderator_options'] = "Moderator Options";
$l['approve_event'] = "Approve Event";
$l['unapprove_event'] = "Unapprove Event";
$l['move_event'] = "Move Event";
$l['repeats_every_day'] = "Repeats every day";
$l['repeats_every_x_days'] = "Repeats every {1} days";
$l['repeats_on_weekdays'] = "Repeats Monday through Friday";
$l['every_week_on_days'] = "Repeats every week on {1}";
$l['every_week'] = "Repeats every week";
$l['every_x_weeks_on_days'] = "Repeats every {1} weeks on<br />{2}";
$l['every_x_weeks'] = "Repeats every {1} weeks";
$l['every_month_on_day'] = "Repeats on day {1}<br />of every month";
$l['every_x_months_on_day'] = "Repeats on day {1}<br />of every {2} months";
$l['every_month_on_weekday'] = "Repeats on the {1} {2}<br />of every month";
$l['every_x_months_on_weekday'] = "Repeats on the {1} {2}<br />of every {3} months";
$l['weekday_occurance_1'] = "first";
$l['weekday_occurance_2'] = "second";
$l['weekday_occurance_3'] = "third";
$l['weekday_occurance_4'] = "fourth";
$l['weekday_occurance_last'] = "last";
$l['every_year_on_day'] = "Repeats every year on {1} {2}";
$l['every_x_years_on_day'] = "Repeats every {3} years on {1} {2}";
$l['every_year_on_weekday'] = "Repeats on the {1} {2} in {3} of every year";
$l['every_x_year_on_weekday'] = "Repeats on the {1} {2} in {3} every {4} years";
$l['delete_event'] = "Delete Event";
$l['delete_q'] = "Delete?";
$l['delete_1'] = "To delete this event, check the checkbox to the left and then click the button to the right.";
$l['delete_2'] = "<b>Note:</b> This process cannot be undone.";
$l['delete_now'] = "Delete Now";
$l['jump_to_calendar'] = "Jump to calendar:";
$l['select_calendar'] = "Calendar:";
$l['type_single'] = "Single day event";
$l['type_ranged'] = "Ranged or recurring event";
$l['enter_time'] = "Time:";
$l['start_time'] = "Starts:";
$l['end_time'] = "Finishes:";
$l['timezone'] = "Time Zone:";
$l['ignore_timezone'] = "<strong>Ignore time zone:</strong> This event should use the time zone of the viewer.";
$l['repeats'] = "Repeats:";
$l['does_not_repeat'] = "Does not repeat";
$l['repeats_daily'] = "Daily";
$l['repeats_weekdays'] = "Every weekday (Mon-Fri)";
$l['repeats_weekly'] = "Weekly";
$l['repeats_every'] = "Repeats every";
$l['day_or_days'] = "day(s)";
$l['week_or_weeks_on'] = "week(s) on";
$l['repeats_monthly'] = "Monthly";
$l['repeats_yearly'] = "Yearly";
$l['repeats_on_day'] = "Repeats on day";
$l['of_every'] = "of every";
$l['month_or_months'] = "month(s)";
$l['repeats_on_the'] = "Repeats on the";
$l['day_of_every'] = "day every";
$l['repeats_on'] = "Repeats on";
$l['every'] = "every";
$l['year_or_years'] = "year(s)";
$l['of'] = "of";
$l['move_to_calendar'] = "Move to Calendar:";
$l['weekly_overview'] = "Weekly Overview";
$l['previous_week'] = "Previous Week";
$l['next_week'] = "Next Week";
$l['first'] = "First";
$l['second'] = "Second";
$l['third'] = "Third";
$l['fourth'] = "Fourth";
$l['last'] = "Last";
$l['all_day'] = "All Day";
$l['starts'] = "Starts: ";
$l['finishes'] = "Finishes: ";

$l['error_incorrectday'] = "The day you have entered does not appear to exist. Please go back and try again.";
$l['error_invalidevent'] = "The event you specified is either invalid or doesn't exist.";
$l['invalid_calendar'] = "The specified calendar does not exist. Are you sure you are visiting the correct page?";
$l['redirect_eventdeleted'] = "The event has successfully been deleted.<br />You will now be taken back to the calendar.";
$l['redirect_eventupdated'] = "The event has been successfully updated.<br />You will now be returned to it.";
$l['redirect_eventadded'] = "Your event has been added successfully.<br />You will now be taken to it.";
$l['redirect_eventadded_moderation'] = "Your event has been added successfully but requires moderation by a forum moderator before it is visible.<br />You will now be taken back to the calendar.";
$l['redirect_eventunapproved'] = "The event has been unapproved successfully.<br />You will now be taken to it.";
$l['redirect_eventapproved'] = "The event has been approved successfully.<br />You will now be taken to it.";
?>
